@@ -16,7 +16,7 @@
 #' @param operator Type of constraint: equality, inequality on one side or both sides.
 #' @param filter_year_by_year Marginal price granularity for year by year
 #' @param filter_synthesis Marginal price granularity for synthesis
-#' @param coefficients A named vector containing the coefficients used by the constraint.
+#' @param coefficients A named vector containing the coefficients used by the constraint, the coefficients have to be alphabetically ordered.
 #' @param overwrite If the constraint already exist, overwrite the previous value.
 #' 
 #' @template opts
@@ -81,6 +81,21 @@ createBindingConstraint <- function(name,
   timeStep <- match.arg(arg = timeStep)
   operator <- match.arg(arg = operator)
   
+  ## Values
+  checked_values <- .valueCheck(values, timeStep)
+  
+  if(!is.null(coefficients)){
+    names_coef <- names(coefficients)
+    splitted_names <- strsplit(names_coef, "%")
+    are_areas_sorted <- sapply(splitted_names, function(areas) {
+      identical(areas, sort(areas))
+    })
+    
+    if (!all(are_areas_sorted)) {
+      stop("The areas are not sorted alphabetically.", call. = FALSE)
+    }
+  }
+
   # API block
   if (is_api_study(opts)) {
     
@@ -90,7 +105,7 @@ createBindingConstraint <- function(name,
       enabled = enabled,
       time_step = timeStep,
       operator = operator,
-      values = values,
+      values = checked_values,
       coeffs = lapply(as.list(coefficients), as.list)
     )
     
@@ -112,7 +127,7 @@ createBindingConstraint <- function(name,
     bindingConstraints,
     name,
     id,
-    values,
+    values = checked_values,
     enabled,
     timeStep,
     operator,
@@ -126,7 +141,7 @@ createBindingConstraint <- function(name,
   
   # Write Ini
   writeIni(listData = bindingConstraints, pathIni = pathIni, overwrite = TRUE)
-
+  
   # Maj simulation
   suppressWarnings({
     res <- antaresRead::setSimulationPath(path = opts$studyPath, simulation = "input")
@@ -186,7 +201,7 @@ createBindingConstraint_ <- function(bindingConstraints,
     #these lines are here to correct this behaviour
     #see https://github.com/r-lib/testthat/issues/144
     #and https://github.com/r-lib/testthat/issues/86
-    #set Sys.setenv("R_TESTS" = "") do nothing 
+    #set Sys.setenv("R_TESTS" = "") do nothing
     resLinks <- strsplit(links, "%")
     for(i in seq_along(resLinks)){
       resLinks[[i]] <- paste(resLinks[[i]][2], resLinks[[i]][1], sep = "%")
@@ -210,8 +225,6 @@ createBindingConstraint_ <- function(bindingConstraints,
   }
   bindingConstraints[[indexBC]] <- c(iniParams, coefficients)
   
-  ## Values
-  values <- .valueCheck(values, timeStep)
   
   # Write values
   pathValues <- file.path(opts$inputPath, "bindingconstraints", paste0(id, ".txt"))
